pub fn generate_codomain(
input_parameters: &InputParameters,
codomain_function: &CodomainFunction,
rng: &mut ChaChaRng,
) -> Vec<Vec<f64>>Expand description
Generate the codomain, by calling the right generation function
pub fn generate_codomain(
input_parameters: &InputParameters,
codomain_function: &CodomainFunction,
rng: &mut ChaChaRng,
) -> Vec<Vec<f64>>Generate the codomain, by calling the right generation function