generate_codomain_and_problem

Function generate_codomain_and_problem 

pub fn generate_codomain_and_problem(
    input_configuration_file_path: &Path,
    output_codomain_folder_path: Option<&Path>,
    output_problem_folder_path: Option<&Path>,
    number_of_problems_to_generate: u32,
    rng: &mut ChaChaRng,
) -> Result<(), Box<dyn Error>>
Generate codomain and problem files for the input configuration as read from the input_configuration_file. If the output_(codomain/problem)_folder_path is None, we default to folder paths used in other parts of the program (codomain_files & problems). If they are Some(path), we use the path as the destination folder.